@@ -22,6 +22,7 @@ from rasa.core.events import (
     BotUttered,
 )
 from rasa.utils.endpoints import EndpointConfig, ClientResponseError
+from rasa.utils.timer import timeit
 
 if typing.TYPE_CHECKING:
     from rasa.core.trackers import DialogueStateTracker
@@ -178,6 +179,7 @@ class ActionUtterTemplate(Action):
         self.template_name = name
         self.silent_fail = silent_fail
 
+    @timeit
     async def run(self, output_channel, nlg, tracker, domain):
         """Simple run implementation uttering a (hopefully defined) template."""
 
