@@ -372,19 +372,6 @@ class MessageProcessor(object):
             self.domain,
         )
 
-        if self._is_goodbye_msg_callback_received(tracker) and tracker.get_slot('outcome') != 'Transfer':
-            outcome = "Disconnected"
-            if tracker.get_latest_input_channel() and tracker.get_latest_input_channel().startswith('OMNI_VOICE'):
-                outcome = "Hangup"
-
-            evt = {
-                "name": "CONVERSATION_END",
-                "message": outcome,
-                "timestamp": int(round(time.time() * 1000))
-            }
-            tracker.update(SlotSet("system_event", evt))
-            tracker.update(SlotSet("outcome", outcome))
-
         if parse_data["entities"]:
             self._log_slots(tracker)
 
@@ -400,16 +387,12 @@ class MessageProcessor(object):
             or tracker.latest_message.intent.get("name") == USER_INTENT_RESTART
         )
 
-    @staticmethod
-    def _is_goodbye_msg_callback_received(tracker):
-        return tracker.current_state().get('latest_message').get('text') == '/goodbye'
-
     @timeit
     async def _predict_and_execute_next_action(
         self, message: UserMessage, tracker: DialogueStateTracker
     ):
         # keep taking actions decided by the policy until it chooses to 'listen'
-        should_predict_another_action = True and not self._is_goodbye_msg_callback_received(tracker)
+        should_predict_another_action = True
         num_predicted_actions = 0
 
         def is_action_limit_reached():
