@@ -110,7 +110,7 @@ async def replay_events(tracker: DialogueStateTracker, agent: "Agent") -> None:
                             cli_utils.button_to_string(button, idx), color=color
                         )
 
-            tracker = await agent.tracker_store.retrieve(tracker.sender_id)
+            tracker = agent.tracker_store.retrieve(tracker.sender_id)
             last_prediction = actions_since_last_utterance(tracker)
 
         elif isinstance(event, ActionExecuted):
