@@ -21,7 +21,7 @@ class MitieTokenizer(Tokenizer, Component):
         for example in training_data.training_examples:
             example.set("tokens", self.tokenize(example.text))
 
-    def process(self, message: Message, **kwargs: Any) -> None:
+    async def process(self, message: Message, **kwargs: Any) -> None:
 
         message.set("tokens", self.tokenize(message.text))
 
