@@ -43,12 +43,21 @@ from rasa.nlu.emulators.no_emulator import NoEmulator
 from rasa.nlu.test import run_evaluation
 from prometheus_client import CollectorRegistry, multiprocess, generate_latest
 from rasa.core.tracker_store import TrackerStore
+import requests
+import re
 
 logger = logging.getLogger(__name__)
 
 OUTPUT_CHANNEL_QUERY_KEY = "output_channel"
 USE_LATEST_INPUT_CHANNEL_AS_OUTPUT_CHANNEL = "latest"
 
+AGENT_USERNAME = "cc6ccd9e-586c-48b5-af2c-bd152349fba7"
+AGENT_PASSWORD = "dal:Cd-YOx50RPWtDTMgW8qKcA"
+CLIENT_ID = "ce5cf308116da3bcb7371856b822fd43"
+
+
+
+
 
 class ErrorResponse(Exception):
     def __init__(self, status, reason, message, details=None, help_url=None):
@@ -1050,6 +1059,59 @@ def create_app(
 
     CHAT_LATENCY.labels('', '').time()
 
+    @app.post("/agent/response")
+    #@requires_auth(app, auth_token)
+    async def process_response(request: Request):
+
+        data = {
+            "chat_id": request.json.get("payload").get("chat_id")
+        }
+
+        chat_thread = requests.post(
+            url="https://api.livechatinc.com/v3.2/agent/action/get_chat",
+            auth=requests.auth.HTTPBasicAuth(AGENT_USERNAME, AGENT_PASSWORD),
+            json=data
+        )
+
+        conversation_id = chat_thread.json().get("properties").get(CLIENT_ID).get("conversation_id")
+
+        if request.json.get("action") == "incoming_event":
+            action_to_execute = "action_human_to_user"
+        else:
+            action_to_execute = "action_human_end_conversation"
+
+        policy = "LiveChatPolicy"
+        confidence = 1
+        verbosity = "ALL"
+
+        try:
+            tracker = obtain_tracker_store(app.agent, conversation_id)
+            if tracker.latest_message.text == "/disconnect":
+                return response.json(None, 200)
+            if tracker.get_slot("handoff_active"):
+                output_channel = _get_output_channel_without_request(app, tracker)
+                await app.agent.execute_action(
+                    conversation_id, action_to_execute, output_channel, policy, confidence
+                )
+        except Exception as e:
+            logger.debug(traceback.format_exc())
+            raise ErrorResponse(
+                500,
+                "ConversationError",
+                "An unexpected error occurred. Error: {}".format(e),
+            )
+
+        tracker = obtain_tracker_store(app.agent, conversation_id)
+        state = tracker.current_state(verbosity)
+
+        response_body = {"tracker": state}
+
+        if isinstance(output_channel, CollectingOutputChannel):
+            response_body["messages"] = output_channel.messages
+
+        return response.json(response_body, 200)
+        
+
     return app
 
 
@@ -1091,3 +1153,42 @@ def _get_output_channel(
         matching_channels,
         CollectingOutputChannel(),
     )
+
+def _get_output_channel_without_request(
+app, tracker: Optional[DialogueStateTracker]
+) -> OutputChannel:
+    """Returns the `OutputChannel` which should be used for the bot's responses.
+
+    Args:
+        request: HTTP request whose query parameters can specify which `OutputChannel`
+                 should be used.
+        tracker: Tracker for the conversation. Used to get the latest input channel.
+
+    Returns:
+        `OutputChannel` which should be used to return the bot's responses to.
+    """
+    requested_output_channel = "latest"
+
+    if (
+        requested_output_channel == USE_LATEST_INPUT_CHANNEL_AS_OUTPUT_CHANNEL
+        and tracker
+    ):
+        requested_output_channel = "webchat"
+
+    # Interactive training does not set `input_channels`, hence we have to be cautious
+    registered_input_channels = getattr(app, "input_channels", None) or []
+    matching_channels = [
+        channel
+        for channel in registered_input_channels
+        if channel.name() == requested_output_channel
+    ]
+    
+    # Check if matching channels can provide a valid output channel,
+    # otherwise use `CollectingOutputChannel`
+    return reduce(
+        lambda output_channel_created_so_far, input_channel: (
+            input_channel.get_output_channel() or output_channel_created_so_far
+        ),
+        matching_channels,
+        CollectingOutputChannel(),
+    )
\ No newline at end of file
